@@ -1,5 +1,5 @@
 /*
- * This file is part of the Nepomuk KDE project.
+ * This file is part of the Baloo KDE project.
  * Copyright (C) 2006-2010 Sebastian Trueg <trueg@kde.org>
  * Copyright (C) 2011-2013 Vishesh Handa <me@vhanda.in>
  *
@@ -28,9 +28,9 @@
 #include <KLocalizedString>
 #include <KJob>
 
-#include <QtWidgets/QPushButton>
-#include <QtWidgets/QBoxLayout>
-#include <QtWidgets/QLabel>
+#include <QPushButton>
+#include <QBoxLayout>
+#include <QLabel>
 
 using namespace Baloo;
 
@@ -38,8 +38,8 @@ void TagWidgetPrivate::init( TagWidget* parent )
 {
     q = parent;
     m_readOnly = false;
-    m_showAllLinkLabel = 0;
-    m_editTagsDialog = 0;
+    m_showAllLinkLabel = nullptr;
+    m_editTagsDialog = nullptr;
 
     QGridLayout* mainLayout = new QGridLayout( q );
     mainLayout->setMargin(0);
@@ -66,7 +66,7 @@ void TagWidgetPrivate::buildTagHash(const QStringList& tags)
     }
 
     delete m_showAllLinkLabel;
-    m_showAllLinkLabel = 0;
+    m_showAllLinkLabel = nullptr;
 
     if (m_readOnly && !tags.isEmpty()) {
         return;
@@ -82,7 +82,7 @@ void TagWidgetPrivate::buildTagHash(const QStringList& tags)
         f.setUnderline(true);
         m_showAllLinkLabel->setFont(f);
         m_showAllLinkLabel->setText( QLatin1String("<a href=\"add_tags\">") +
-                                        ( m_checkBoxHash.isEmpty() ? i18nc("@label", "Add...") : i18nc("@label", "Change...") ) +
+                                        ( m_checkBoxHash.isEmpty() ? i18nc("@label", "Add...") : i18nc("@label", "Edit...") ) +
                                         QLatin1String("</a>") );
         q->connect( m_showAllLinkLabel, SIGNAL(linkActivated(QString)), SLOT(slotShowAll()) );
     }
@@ -185,6 +185,6 @@ void TagWidget::slotKEditTagDialogFinished(int result)
     }
 
     d->m_editTagsDialog->deleteLater();
-    d->m_editTagsDialog = 0;
+    d->m_editTagsDialog = nullptr;
 }
 
